@@ -365,7 +365,9 @@ class DockerVolumes:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DockerVolumes.__init__)
+            def stub(*, container_path: builtins.str, host_path: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument container_path", value=container_path, expected_type=type_hints["container_path"])
             check_type(argname="argument host_path", value=host_path, expected_type=type_hints["host_path"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -476,7 +478,32 @@ class GitlabContainerRunner(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GitlabContainerRunner.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                gitlabtoken: builtins.str,
+                concurrent_jobs: typing.Optional[jsii.Number] = None,
+                docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+                ebs_size: typing.Optional[jsii.Number] = None,
+                ec2iamrole: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                ec2type: typing.Optional[builtins.str] = None,
+                gitlab_runner_image: typing.Optional[builtins.str] = None,
+                gitlaburl: typing.Optional[builtins.str] = None,
+                instance_interruption_behavior: typing.Optional["InstanceInterruptionBehavior"] = None,
+                key_name: typing.Optional[builtins.str] = None,
+                runner_description: typing.Optional[builtins.str] = None,
+                selfvpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                spot_fleet: typing.Optional[builtins.bool] = None,
+                tag1: typing.Optional[builtins.str] = None,
+                tag2: typing.Optional[builtins.str] = None,
+                tag3: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+                valid_until: typing.Optional[builtins.str] = None,
+                vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitlabContainerRunnerProps(
@@ -518,7 +545,12 @@ class GitlabContainerRunner(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GitlabContainerRunner.create_user_data)
+            def stub(
+                props: typing.Union["GitlabContainerRunnerProps", typing.Dict[str, typing.Any]],
+                token_parameter_store_name: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument props", value=props, expected_type=type_hints["props"])
             check_type(argname="argument token_parameter_store_name", value=token_parameter_store_name, expected_type=type_hints["token_parameter_store_name"])
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "createUserData", [props, token_parameter_store_name]))
@@ -532,7 +564,9 @@ class GitlabContainerRunner(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GitlabContainerRunner.expire_after)
+            def stub(duration: aws_cdk.Duration) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument duration", value=duration, expected_type=type_hints["duration"])
         return typing.cast(None, jsii.invoke(self, "expireAfter", [duration]))
 
@@ -667,7 +701,30 @@ class GitlabContainerRunnerProps:
         if isinstance(vpc_subnet, dict):
             vpc_subnet = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnet)
         if __debug__:
-            type_hints = typing.get_type_hints(GitlabContainerRunnerProps.__init__)
+            def stub(
+                *,
+                gitlabtoken: builtins.str,
+                concurrent_jobs: typing.Optional[jsii.Number] = None,
+                docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+                ebs_size: typing.Optional[jsii.Number] = None,
+                ec2iamrole: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                ec2type: typing.Optional[builtins.str] = None,
+                gitlab_runner_image: typing.Optional[builtins.str] = None,
+                gitlaburl: typing.Optional[builtins.str] = None,
+                instance_interruption_behavior: typing.Optional["InstanceInterruptionBehavior"] = None,
+                key_name: typing.Optional[builtins.str] = None,
+                runner_description: typing.Optional[builtins.str] = None,
+                selfvpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                spot_fleet: typing.Optional[builtins.bool] = None,
+                tag1: typing.Optional[builtins.str] = None,
+                tag2: typing.Optional[builtins.str] = None,
+                tag3: typing.Optional[builtins.str] = None,
+                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+                valid_until: typing.Optional[builtins.str] = None,
+                vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument gitlabtoken", value=gitlabtoken, expected_type=type_hints["gitlabtoken"])
             check_type(argname="argument concurrent_jobs", value=concurrent_jobs, expected_type=type_hints["concurrent_jobs"])
             check_type(argname="argument docker_volumes", value=docker_volumes, expected_type=type_hints["docker_volumes"])
@@ -1107,7 +1164,28 @@ class GitlabRunnerAutoscaling(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GitlabRunnerAutoscaling.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                gitlab_token: builtins.str,
+                alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
+                desired_capacity: typing.Optional[jsii.Number] = None,
+                docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+                ebs_size: typing.Optional[jsii.Number] = None,
+                gitlab_runner_image: typing.Optional[builtins.str] = None,
+                gitlab_url: typing.Optional[builtins.str] = None,
+                instance_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                instance_type: typing.Optional[builtins.str] = None,
+                max_capacity: typing.Optional[jsii.Number] = None,
+                min_capacity: typing.Optional[jsii.Number] = None,
+                spot_instance: typing.Optional[builtins.bool] = None,
+                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitlabRunnerAutoscalingProps(
@@ -1301,7 +1379,26 @@ class GitlabRunnerAutoscalingProps:
         if isinstance(vpc_subnet, dict):
             vpc_subnet = aws_cdk.aws_ec2.SubnetSelection(**vpc_subnet)
         if __debug__:
-            type_hints = typing.get_type_hints(GitlabRunnerAutoscalingProps.__init__)
+            def stub(
+                *,
+                gitlab_token: builtins.str,
+                alarms: typing.Optional[typing.Sequence[typing.Mapping[typing.Any, typing.Any]]] = None,
+                desired_capacity: typing.Optional[jsii.Number] = None,
+                docker_volumes: typing.Optional[typing.Sequence[typing.Union[DockerVolumes, typing.Dict[str, typing.Any]]]] = None,
+                ebs_size: typing.Optional[jsii.Number] = None,
+                gitlab_runner_image: typing.Optional[builtins.str] = None,
+                gitlab_url: typing.Optional[builtins.str] = None,
+                instance_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+                instance_type: typing.Optional[builtins.str] = None,
+                max_capacity: typing.Optional[jsii.Number] = None,
+                min_capacity: typing.Optional[jsii.Number] = None,
+                spot_instance: typing.Optional[builtins.bool] = None,
+                tags: typing.Optional[typing.Sequence[builtins.str]] = None,
+                vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+                vpc_subnet: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument gitlab_token", value=gitlab_token, expected_type=type_hints["gitlab_token"])
             check_type(argname="argument alarms", value=alarms, expected_type=type_hints["alarms"])
             check_type(argname="argument desired_capacity", value=desired_capacity, expected_type=type_hints["desired_capacity"])
